@@ -48,8 +48,8 @@ static class g711u : public AudioCodec
 public:
 	g711u();
 
-	unsigned encode(Linear buffer, void *source, unsigned lsamples);
-	unsigned decode(Linear buffer, void *dest, unsigned lsamples);
+	unsigned encode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize);
+	unsigned decode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize);
 	Level getImpulse(void *buffer, unsigned samples);
 	Level getPeak(void *buffer, unsigned samples);
 
@@ -60,8 +60,8 @@ static class g711a : public AudioCodec
 public:
 	g711a();
 
-	unsigned encode(Linear buffer, void *source, unsigned lsamples);
-	unsigned decode(Linear buffer, void *dest, unsigned lsamples);
+	unsigned encode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize);
+	unsigned decode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize);
 	Level getImpulse(void *buffer, unsigned samples);
 	Level getPeak(void *buffer, unsigned samples);
 
@@ -150,7 +150,7 @@ Audio::Level g711u::getPeak(void *data, unsigned samples)
 	return max;
 }
 
-unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples)
+unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize)
 {
 	static int ulaw[256] = {
         0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,
@@ -173,7 +173,12 @@ unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples)
 	register Sample sample;
 	int sign, exponent, mantissa, retval;
 	register unsigned char *d = (unsigned char *)dest;
-	unsigned count = lsamples;
+	unsigned count;
+
+	if(bufsize && bufsize < lsamples)
+		lsamples = bufsize;
+
+	count = lsamples;
 
 	while(lsamples--)
 	{
@@ -191,10 +196,15 @@ unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples)
 	return count;
 }
 
-unsigned g711u::decode(Linear buffer, void *source, unsigned lsamples)
+unsigned g711u::decode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize)
 {
 	register unsigned char *src = (unsigned char *)source;
-	unsigned count = lsamples;
+	unsigned count;
+
+	if(bufsize && bufsize < lsamples)
+		lsamples = bufsize;
+
+	count = lsamples;
 
 	static Sample values[256] =
 	{
@@ -240,15 +250,20 @@ unsigned g711u::decode(Linear buffer, void *source, unsigned lsamples)
 
 #define	AMI_MASK	0x55
 
-unsigned g711a::encode(Linear buffer, void *dest, unsigned lsamples)
+unsigned g711a::encode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize)
 {
 	int mask, seg, pcm_val;
-	unsigned count = lsamples;
+	unsigned count;
 	unsigned char *d = (unsigned char *)dest;
 
 	static int seg_end[] = {
 		0xFF, 0x1FF, 0x3FF, 0x7FF, 0xFFF, 0x1FFF, 0x3FFF, 0x7FFF};
 
+	if(bufsize && bufsize < lsamples)
+		lsamples = bufsize;
+
+	count = lsamples;
+
 	while(lsamples--)
 	{
 		pcm_val = *(buffer++);
@@ -326,10 +341,10 @@ Audio::Level g711a::getPeak(void *data, unsigned samples)
 	return max;
 }
 
-unsigned g711a::decode(Linear buffer, void *source, unsigned lsamples)
+unsigned g711a::decode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize)
 {
 	register unsigned char *src = (unsigned char *)source;
-	unsigned count = lsamples;
+	unsigned count;
 
 	static Sample values[256] =
 	{
@@ -367,6 +382,11 @@ unsigned g711a::decode(Linear buffer, void *source, unsigned lsamples)
 	      944,    912,   1008,    976,    816,    784,    880,    848
  	};
 
+	if(bufsize && bufsize < lsamples)
+		lsamples = bufsize;
+
+	count = lsamples;
+
 	while(lsamples--)
 		*(buffer++) = values[*(src++)];
 
