@@ -90,8 +90,8 @@ protected:
 
 	Sample decoder(int code);
 	unsigned char encoder(Sample sample);
-	unsigned encode(Linear buffer, void *dest, unsigned lsamples);
-	unsigned decode(Linear buffer, void *source, unsigned lsamples);
+	unsigned encode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize);
+	unsigned decode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize);
 };
 
 class g723_24 : protected g72x, protected AudioCodec
@@ -101,8 +101,8 @@ protected:
 
 	g723_24();
 
-        unsigned encode(Linear buffer, void *source, unsigned lsamples);
-        unsigned decode(Linear buffer, void *dest, unsigned lsamples);
+        unsigned encode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize);
+        unsigned decode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize);
 };
 
 class g723_40 : protected g72x, protected AudioCodec
@@ -112,8 +112,8 @@ protected:
 
 	g723_40();
 
-        unsigned encode(Linear buffer, void *source, unsigned lsamples);
-        unsigned decode(Linear buffer, void *dest, unsigned lsamples);
+        unsigned encode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize);
+        unsigned decode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize);
 };
 
 static class g723 : public AudioCodec
@@ -125,10 +125,10 @@ static class g723 : public AudioCodec
 public:
 	g723(Encoding encoding);
 
-	unsigned encode(Linear buffer, void *source, unsigned lsamples)
+	unsigned encode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize)
 		{return 0;};
 
-	unsigned decode(Linear buffer, void *dest, unsigned lsamples)
+	unsigned decode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize)
 		{return 0;};
 
 	AudioCodec *getByFormat(const char *format);
@@ -593,11 +593,14 @@ unsigned char g723_16::encoder(Sample sl)
 
 }
 
-unsigned g723_16::decode(Linear buffer, void *source, unsigned lsamples)
+unsigned g723_16::decode(Linear buffer, void *source, unsigned lsamples, unsigned bufsize)
 {
 	unsigned char code, *dp = (unsigned char *)source;
 	unsigned count = 0;
 
+	if(bufsize && bufsize < (lsamples / 4))
+		lsamples = bufsize * 4;
+
 	while(lsamples > 3)
 	{
 		code = *(dp++);
@@ -611,11 +614,14 @@ unsigned g723_16::decode(Linear buffer, void *source, unsigned lsamples)
 	return count;
 }
 	
-unsigned g723_16::encode(Linear buffer, void *dest, unsigned lsamples)
+unsigned g723_16::encode(Linear buffer, void *dest, unsigned lsamples, unsigned bufsize)
 {
 	unsigned char *dp, code;
 	unsigned count = 0;
 
+	if(bufsize && bufsize < (lsamples / 4))
+		lsamples = bufsize * 4;
+
 	while(lsamples > 3)
 	{
 		code = encoder(*(buffer++));
