@@ -475,6 +475,15 @@ public:
 	 */
 	static bool isLinear(Encoding encoding);
 
+	/**
+	 * Test if the audio encoding format must be packetized (that
+	 * is, has irregular sized frames).
+	 *
+	 * @return true if packetized audio.
+	 * @param encoding format.
+	 */
+	static bool isPacket(Encoding encoding);
+
 	/**
 	 * Test if the audio encoding format is a mono format.
 	 *
@@ -815,9 +824,8 @@ public:
 	 * standard endian representation (byte swap) if needed.
 	 *
 	 * @return pointer to samples.
-	 * @param endian assumed for linear data if true.
 	 */
-	virtual Linear getFrame(bool endian = false);	
+	virtual Linear getFrame(void);	
 
 	/**
 	 * This is used to copy one or more pages of framed audio
@@ -1801,8 +1809,9 @@ public:
 	 * @param buffer linear sample buffer to use.
 	 * @param dest buffer to store encoded results.
 	 * @param number of linear samples.
+	 * @param size of destination buffer.
 	 */
-	virtual unsigned encode(Linear buffer, void *dest, unsigned number) = 0;
+	virtual unsigned encode(Linear buffer, void *dest, unsigned number = 0, unsigned bufsize = 0) = 0;
 
 	/**
 	 * Decode the sample frame into linear samples.
@@ -1811,8 +1820,9 @@ public:
 	 * @param buffer sample buffer to save linear samples into.
 	 * @param source for encoded data.
 	 * @param number of samples to extract.
+	 * @patam size of source buffer.
 	 */
-	virtual unsigned decode(Linear buffer, void *source, unsigned number) = 0;
+	virtual unsigned decode(Linear buffer, void *source, unsigned number = 0, unsigned bufsize = 0) = 0;
 
 	/**
 	 * Get an info description for this codec.
@@ -1840,15 +1850,6 @@ public:
 	 */
 	virtual unsigned putSamples(Linear buffer, unsigned count) = 0;
 
-	/**
-	 * Copy linear samples to an audio device from native endian.
-	 *
-	 * @param buffer to linear audio data.
-	 * @param count of audio samples to play.
-	 * @return number of audio samples played.
-	 */
-	unsigned putNativeSamples(Linear buffer, unsigned count);
-
         /** 
          * Copy linear samples from an audio device through its virtual.
          *
@@ -1858,15 +1859,6 @@ public:
          */
 	virtual unsigned getSamples(Linear buffer, unsigned count) = 0;
 
-	/**
-	 * Copy linear samples from an audio device into native endian.
-	 *
-	 * @param buffer for recording.
-	 * @param count of audio samples to record.
-	 * @return number of audio samples recorded.
-	 */
-	unsigned getNativeSamples(Linear buffer, unsigned count);
-
 	/**
 	 * Copy audio encoded in the currently selected encoding for
 	 * the audio device.
@@ -2006,9 +1998,8 @@ public:
 	 * the telephony tone sequence being created.
 	 *
 	 * @return pointer to samples generated.
-	 * @param endian set true if converted.
 	 */
-	Linear getFrame(bool endian = false);
+	Linear getFrame(void);
 
 	/**
 	 * Check if all audio frames for this tone has been created.
@@ -2077,7 +2068,7 @@ public:
 
 	~DTMFTones();
 
-	Linear getFrame(bool endian = false);
+	Linear getFrame(void);
 	bool isComplete(void);
 };
 
@@ -2112,7 +2103,7 @@ public:
 
 	~MFTones();
 
-	Linear getFrame(bool endian = false);
+	Linear getFrame(void);
 	bool isComplete(void);
 };
 
