@@ -227,7 +227,7 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return mulawAudio;
 	else if(!stricmp(name, "alaw") || !stricmp(name, "pcma"))
 		return alawAudio;
-	else if(!stricmp(name, "linear") || !stricmp(name, "pcm16") || !stricmp(name, "pcm"))
+	else if(!stricmp(name, "linear") || !stricmp(name, "pcm16") || !stricmp(name, "pcm") || !stricmp(name, "l16"))
 		return pcm16Mono;
 	else if(!stricmp(name, "cda"))
 		return cdaStereo;
@@ -235,7 +235,7 @@ Audio::Encoding Audio::getEncoding(const char *name)
 		return gsmVoice;
 	else if(!stricmp(name, "msgsm"))
 		return msgsmVoice;
-	else if(!stricmp(name, "pcm8"))
+	else if(!stricmp(name, "pcm8") || !stricmp(name, "l8"))
 		return pcm8Mono;
 	else if(!stricmp(name, "pcm32"))
 		return pcm32Mono;
@@ -331,7 +331,7 @@ const char *Audio::getName(Encoding encoding)
 	case cdaMono:
 	case pcm16Stereo:
 	case pcm16Mono:
-		return "pcm";
+		return "pcm16";
 	case pcm32Stereo:
 	case pcm32Mono:
 		return "pcm32";
@@ -374,6 +374,18 @@ const char *Audio::getName(Encoding encoding)
 	return "unknown";
 }
 
+bool Audio::isPacket(Encoding encoding)
+{
+	switch(encoding)
+	{
+	case mp1Audio:
+	case mp2Audio:
+	case mp3Audio:
+		return true;
+	}
+	return false;
+} 
+
 bool Audio::isLinear(Encoding encoding)
 {
 	switch(encoding)
