@@ -97,11 +97,11 @@ void AudioBuild::copyConvert(AudioStream &input, AudioStream &output)
 
 void AudioBuild::copyDirect(AudioStream &input, AudioStream &output)
 {
-	unsigned samples, bufsize;
+	unsigned bufsize;
 	Encoded buffer;
 	Info from, to;
 	bool endian = false;
-	Error status = errSuccess;
+	ssize_t status = 1;
 
 	input.getInfo(&from);
 	output.getInfo(&to);
@@ -109,23 +109,16 @@ void AudioBuild::copyDirect(AudioStream &input, AudioStream &output)
         if(to.order && from.order && to.order != from.order && isLinear(from.encoding))
                 endian = true;
 	
-        samples = from.framecount;
         bufsize = from.framesize;
         buffer = new unsigned char[bufsize];
 
-	while(status == errSuccess)
+	while(status > 0)
         {
-                status = input.getSamples(buffer, samples);      
-                if(status == errReadIncomplete)
-                        break;
+		status = input.getNative(buffer, bufsize);
+		if(status < 1)
+			break;
 
-                if(endian)
-                {
-                        swapEndian(from, buffer, samples);
-                        swapEndian(to, buffer, samples);
-                }
-
-                status = output.putSamples(buffer, samples);
+                status = output.putNative(buffer, status);
         }
 
 	delete[] buffer;
